<?php

namespace Drupal\acquia_search\EventSubscriber\PossibleCores;

use Drupal\search_api\SearchApiException;
use Drupal\search_api_solr\Event\PreQueryEvent;
use Drupal\search_api_solr\Event\SearchApiSolrEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Alters the EdisMax query on Acquia Search.
 */
class EdisMax implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      SearchApiSolrEvents::PRE_QUERY => 'preQuery',
    ];
  }

  /**
   * Add EdisMax for Acquia Solr Queries.
   *
   * @param \Drupal\search_api_solr\Event\PreQueryEvent $event
   *   The dispatched event.
   */
  public function preQuery(PreQueryEvent $event) {
    $solarium_query = $event->getSolariumQuery();
    $handler = $solarium_query->getHandler();
    $search_index = $event->getSearchApiQuery()->getIndex();
    try {
      $server = $search_index->getServerInstance();
    }
    catch (SearchApiException $exception) {
      return;
    }

    if (empty($server)) {
      return;
    }

    $backend_config = $server->getBackendConfig();
    if (!(!empty($backend_config['connector']) && $backend_config['connector'] === 'solr_acquia_connector')) {
      return;
    }

    if ('select' === $handler) {
      $use_edismax = $search_index->getThirdPartySetting(
        'acquia_search',
        'use_edismax',
        TRUE
      );
      if ($use_edismax) {
        $solarium_query->addParam('defType', 'edismax');
      }
    }
  }

}
